/**
 * @file
 */

Drupal.behaviors.stripe_checkout = {
  attach: function (context, settings) {

    function getParameterByName(name, url) {
      if (!url) {
        url = window.location.href;
      }
      name = name.replace(/[\[\]]/g, "\\$&");
      var regex = new RegExp("[?&]" + name + "(=([^&#]*)|&|#|$)"),
        results = regex.exec(url);
      if (!results) {
        return null;
      }
      if (!results[2]) {
        return '';
      }
      return decodeURIComponent(results[2].replace(/\+/g, " "));
    }

    function initializeStripe(Stripe) {
      document.querySelectorAll('.stripe-checkout-button').forEach(function(elem) {
        elem.addEventListener('click', function(event) {
          stripeClickEventListen(event);
        });
      });
    }

    function stripeClickEventListen(event) {
      var targetElement = event.target;
      var throbber = '<span class="ajax-progress__throbber">&nbsp;</span>';
      jQuery(targetElement).prop('disabled', true).html('Please wait...' + throbber);
      jQuery.ajax({
        url: "/stripe_checkout/create_session",
        method: "POST",
        dataType: 'json',
        data: {
          entity_type: targetElement.dataset.entity_type,
          entity_id: targetElement.dataset.entity_id,
          field_name: targetElement.dataset.field_name,
          delta: targetElement.dataset.delta
        },
        success: function (data, textStatus, jqXHR) {
          redirectToStripe(Stripe, data.session_id);
        },
        error: function (jqXHR, textStatus, errorThrown) {
          window.alert("Something went wrong. Please contact support@guitargate.com and report the following error:\n\n " + errorThrown + ':\n' + jqXHR.responseText);
        }
      });
    }

    function redirectToStripe(Stripe, sessionId) {
      var stripe = Stripe(settings.stripe_checkout.public_key);
      stripe.redirectToCheckout({
        sessionId: sessionId
      }).then(function (result) {
        // If `redirectToCheckout` fails due to a browser or network
        // error, display the localized error message to your customer
        // using `result.error.message`.
      });
    }

    (function ($) {
      // If stripe_checkout_click query parameter is set, then click the stripe button automatically.
      var stripe_checkout_click = getParameterByName('stripe_checkout_click');
      if (stripe_checkout_click) {
        $('.stripe-button-el', context).once('clicked').click();
      }

      initializeStripe(Stripe);
    })(jQuery, Stripe);
  }


};
